# AutoTrader ToDo List
The following items have been bookmarked as to-do items.

## Features
- Sizing Options
- Consolidation of broker utils into single class, with inheritance where 
  necessary
- Optional return of trade summary after backtest, allowing further 
  post-processing
- Automated demonstrations
- Executable command-line run script


### Cleanup
- dict reassignment through virtual broker, utils and AutoTrader
